@@ -17,7 +17,7 @@
 # along with lava-dashboard-tool.  If not, see <http://www.gnu.org/licenses/>.
 
 """
-Launch Control Tool package
+Lava Tool package
 """
 from lava_tool import version
 __version__ = version()
