@@ -670,6 +670,10 @@ class make_stream(XMLRPCCommand):
         print "Bundle stream {pathname} created".format(pathname=pathname)
 
 
+def _round_float_value_2_decimals(value):
+    return "%0.2f" % (round(value, 1),)
+
+
 class pull(XMLRPCCommand):
     """
     Copy bundles and bundle streams from one dashboard to another.
@@ -719,15 +723,13 @@ class pull(XMLRPCCommand):
         except (TypeError, ValueError, UnicodeDecodeError):
             return "%(size)d byte", "%(size)d num_bytes" % {'size': 0}
 
-        filesize_number_format = lambda value: "%0.2f" % (round(value, 1),)
-
         if num_bytes < 1024:
             return "%(size)d bytes" % {'size': num_bytes}
         if num_bytes < 1024 * 1024:
-            return "%s KB" % filesize_number_format(num_bytes / 1024)
+            return "%s KB" % _round_float_value_2_decimals(num_bytes / 1024)
         if num_bytes < 1024 * 1024 * 1024:
-            return "%s MB" % filesize_number_format(num_bytes / (1024 * 1024))
-        return "%s GB" % filesize_number_format(num_bytes / (1024 * 1024 * 1024))
+            return "%s MB" % _round_float_value_2_decimals(num_bytes / (1024 * 1024))
+        return "%s GB" % _round_float_value_2_decimals(num_bytes / (1024 * 1024 * 1024))
 
     def invoke_remote(self):
         self._check_server_version(self.server, "0.3")
