@@ -508,3 +508,61 @@ class compare_device_conf(Command):
         with open(device_file, 'r') as fileh:
             content = fileh.read()
         return jinja2_to_devicedictionary(content)
+
+
+class device_dictionary(Command):
+    """
+    Update or export device dictionary data as jinja2 data.
+    [Superusers only.]
+    """
+
+    def invoke(self):
+        if self.args.update and self.args.export:
+            print >> sys.stderr, "Please use either update or export."
+            return 1
+        elif self.args.export:
+            hostname = str(self.args.DEVICE_HOSTNAME)
+            stream = sys.stdout
+            server = AuthenticatingServerProxy(
+                self.args.SERVER, auth_backend=KeyringAuthBackend())
+            if self.args.export:
+                try:
+                    stream.write(server.scheduler.export_device_dictionary(hostname).data)
+                except xmlrpclib.Fault as exc:
+                    print >> sys.stderr, exc
+                    return -1
+        elif self.args.update:
+            server = AuthenticatingServerProxy(
+                self.args.SERVER, auth_backend=KeyringAuthBackend())
+            hostname = str(self.args.DEVICE_HOSTNAME)
+            filename = self.args.update
+            if not os.path.exists(filename):
+                print >> sys.stderr, "File {filename!r} does not exist".format(
+                    filename=filename)
+                return -1
+            with open(filename, "r") as reader:
+                data = reader.read()
+            print "Updating device dictionary for %s on %s" % (hostname, self.args.SERVER)
+            try:
+                print server.scheduler.import_device_dictionary(hostname, data)
+            except xmlrpclib.Fault as exc:
+                print >> sys.stderr, exc
+                return -1
+        else:
+            print >> sys.stderr, "Unrecognised options."
+            return 2
+
+    def reparse_arguments(self, parser, raw_args):
+        pass
+
+    @classmethod
+    def register_arguments(cls, parser):
+        super(device_dictionary, cls).register_arguments(parser)
+        parser.add_argument("SERVER",
+                            help="Host to query or update the device dictionary on")
+        parser.add_argument("DEVICE_HOSTNAME",
+                            help="DEVICE_HOSTNAME to query or update")
+        parser.add_argument("--update", "-u",
+                            help="Load a jinja2 file to update the device dictionary")
+        parser.add_argument("--export", "-e", action='store_true',
+                            help="Export the device dictionary for this device as jinja2")
